@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-#  Copyright (c) 2020, Markus Binsteiner
+#  Copyright (c) 2020-2021, Markus Binsteiner
 #
 #  Mozilla Public License Version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
@@ -53,7 +53,7 @@ def define_env(env):
         extra_env: Optional[Dict[str, str]] = None,
         fake_command: Optional[str] = None,
     ):
-        """Execute the provided command, save the output and return it to be used in documentation pages."""
+        """Execute the provided command, save the output and return it to be used in documentation modules."""
 
         hashes = DeepHash(command)
         hash_str = hashes[command]
