@@ -1,5 +1,10 @@
 # -*- coding: utf-8 -*-
 
+#  Copyright (c) 2021, University of Luxembourg / DHARPA project
+#  Copyright (c) 2021, Markus Binsteiner
+#
+#  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
+
 from click.testing import CliRunner
 
 from kiara.interfaces.cli import cli
@@ -38,9 +43,13 @@ def test_run_with_valid_inputs():
     assert "True" in result.stdout
 
 
-# def test_run_with_save():
-#
-#     runner = CliRunner()
-#     result = runner.invoke(cli, "run logic.and a=true b=true")
-#     assert result.exit_code == 0
-#     assert "True" in result.stdout
+def test_run_with_save():
+
+    runner = CliRunner(env={"KIARA_DATA_STORE": "/tmp/kiara_save_test"})
+    runner.invoke(cli, "data clear-data-store")
+    result = runner.invoke(cli, "run logic.and a=true b=true --save test_save")
+    assert result.exit_code == 0
+    assert "True" in result.stdout
+
+    result_data = runner.invoke(cli, "data list")
+    assert "test_save-y" in result_data.stdout
